aboutsummaryrefslogtreecommitdiff
path: root/sword2/driver
diff options
context:
space:
mode:
authorMax Horn2003-08-23 14:42:37 +0000
committerMax Horn2003-08-23 14:42:37 +0000
commit01f020da2b82fcc781f4654aefb90fb3033e2196 (patch)
tree555c2a6f4071b5a5f3a360d8717c2fbd8d604057 /sword2/driver
parent4df7dd406f13454944fb62e99343708d44e1dffc (diff)
downloadscummvm-rg350-01f020da2b82fcc781f4654aefb90fb3033e2196.tar.gz
scummvm-rg350-01f020da2b82fcc781f4654aefb90fb3033e2196.tar.bz2
scummvm-rg350-01f020da2b82fcc781f4654aefb90fb3033e2196.zip
SetPalette conflicts with an OS symbol on OS X
svn-id: r9829
Diffstat (limited to 'sword2/driver')
-rw-r--r--sword2/driver/driver96.h6
-rw-r--r--sword2/driver/palette.cpp12
-rw-r--r--sword2/driver/rdwin.cpp4
3 files changed, 11 insertions, 11 deletions
diff --git a/sword2/driver/rdwin.cpp b/sword2/driver/rdwin.cpp
index bfa990e7fb..dfdd68b823 100644
--- a/sword2/driver/rdwin.cpp
+++ b/sword2/driver/rdwin.cpp
@@ -307,12 +307,12 @@ long FAR PASCAL WindowsMessageHandler(HWND hWnd, UINT message, WPARAM wParam, LP
{
int32 hr;
- hr = IDirectDrawSurface_SetPalette(lpPrimarySurface, lpPalette);
+ hr = IDirectDrawSurface_BS2_SetPalette(lpPrimarySurface, lpPalette);
if (hr == DDERR_SURFACELOST)
{
IDirectDrawSurface_Restore(lpPrimarySurface);
- hr= IDirectDrawSurface_SetPalette(lpPrimarySurface, lpPalette);
+ hr= IDirectDrawSurface_BS2_SetPalette(lpPrimarySurface, lpPalette);
if(hr == DDERR_SURFACELOST)
{
Message("Failed to restore palette after second try");
diff --git a/sword2/driver/driver96.h b/sword2/driver/driver96.h
index 1f3163dc28..8dd25de649 100644
--- a/sword2/driver/driver96.h
+++ b/sword2/driver/driver96.h
@@ -113,7 +113,7 @@
// 1.20 03-Dec-96 PRP Sound driver functions added. It is now
// possible to play speech.
//
// 1.21 05-Dec-96 PRP SetPalette changed so that the palette can
// be realized immediately or later when fading
// is called.
//
@@ -443,7 +443,7 @@
// ------------------------------- palette.c --------------------------------
// --------------------------------------------------------------------------
//
// void SetPalette(int32 startEntry, int32 noEntries, uint8 *colourTable, uint8 setNow)
//
// Sets the palette from position startEntry for noEntries, to the data
// pointed to by colourTable. To set the palette immediately pass
@@ -1506,7 +1506,7 @@ extern int32 GetGameName(uint8 *name);
//-----------------------------------------------------------------------------
// Palette functions - from palette.c
//-----------------------------------------------------------------------------
-extern int32 SetPalette(int16 startEntry, int16 noEntries, uint8 *palette, uint8 setNow);
+extern int32 BS2_SetPalette(int16 startEntry, int16 noEntries, uint8 *palette, uint8 setNow);
extern int32 UpdatePaletteMatchTable(uint8 *data);
extern uint8 QuickMatch(uint8 r, uint8 g, uint8 b);
extern int32 FadeUp(float time);
@@ -113,7 +113,7 @@
// possible to play speech.
//
-// 1.21 05-Dec-96 PRP SetPalette changed so that the palette can
+// 1.21 05-Dec-96 PRP BS2_SetPalette changed so that the palette can
// be realized immediately or later when fading
// is called.
@@ -443,7 +443,7 @@
// --------------------------------------------------------------------------
//
-// void SetPalette(int32 startEntry, int32 noEntries, uint8 *colourTable, uint8 setNow)
+// void BS2_SetPalette(int32 startEntry, int32 noEntries, uint8 *colourTable, uint8 setNow)
//
// Sets the palette from position startEntry for noEntries, to the data
diff --git a/sword2/driver/palette.cpp b/sword2/driver/palette.cpp
index 31c26c6972..4d228a237e 100644
--- a/sword2/driver/palette.cpp
+++ b/sword2/driver/palette.cpp
@@ -61,7 +61,7 @@
// speed - but didn't work. Added functions
// to fade the palette up and down.
//
// 1.10 05-Dec-96 PRP Added a flag to SetPalette so that the palette
// can be set immediately or later by the fade.
//
// 1.11 06-Dec-96 JEL fadeStatus now initialised to 0
@@ -91,18 +91,18 @@
//
// 1.21 09-Jul-97 JEL Fixed palette dimming - to unsigned rather than signed RGB values!
//
// 1.22 26-Jun-97 JEL SetPalette now always sets colour 0 to black so doesn't need setting to black from game engine
//
// 1.23 10-Jul-97 JEL Nothing changed but new version had to be booked in anyway.
//
// 1.24 10-Jul-97 JEL SetPalette doesn't do that any more (see above)!
//
// Functions
// ---------
//
// --------------------------------------------------------------------------
//
// void SetPalette(int32 startEntry, int32 noEntries, uint8 *colourTable)
//
// Sets the palette from position startEntry for noEntries, to the data
// pointed to by colourTable.
@@ -315,10 +315,10 @@ uint8 QuickMatch(uint8 r, uint8 g, uint8 b) {
-int32 SetPalette(int16 startEntry, int16 noEntries, uint8 *colourTable, uint8 fadeNow)
+int32 BS2_SetPalette(int16 startEntry, int16 noEntries, uint8 *colourTable, uint8 fadeNow)
{
- debug(0, "SetPalette(%d, %d, %d)", startEntry, noEntries, fadeNow);
+ debug(0, "BS2_SetPalette(%d, %d, %d)", startEntry, noEntries, fadeNow);
StackLock lock(g_sword2->_paletteMutex);
@@ -61,7 +61,7 @@
// to fade the palette up and down.
//
-// 1.10 05-Dec-96 PRP Added a flag to SetPalette so that the palette
+// 1.10 05-Dec-96 PRP Added a flag to BS2_SetPalette so that the palette
// can be set immediately or later by the fade.
//
@@ -91,18 +91,18 @@
// 1.21 09-Jul-97 JEL Fixed palette dimming - to unsigned rather than signed RGB values!
//
-// 1.22 26-Jun-97 JEL SetPalette now always sets colour 0 to black so doesn't need setting to black from game engine
+// 1.22 26-Jun-97 JEL BS2_SetPalette now always sets colour 0 to black so doesn't need setting to black from game engine
//
// 1.23 10-Jul-97 JEL Nothing changed but new version had to be booked in anyway.
@@ -91,18 +91,18 @@
// 1.23 10-Jul-97 JEL Nothing changed but new version had to be booked in anyway.
//
-// 1.24 10-Jul-97 JEL SetPalette doesn't do that any more (see above)!
+// 1.24 10-Jul-97 JEL BS2_SetPalette doesn't do that any more (see above)!
//
// Functions
@@ -91,18 +91,18 @@
// --------------------------------------------------------------------------
//
-// void SetPalette(int32 startEntry, int32 noEntries, uint8 *colourTable)
+// void BS2_SetPalette(int32 startEntry, int32 noEntries, uint8 *colourTable)
//
// Sets the palette from position startEntry for noEntries, to the data